Signature

Struct Signature 

pub struct Signature(/* private fields */);
An Ed25519 signature (64 bytes).

Implementations

Source

impl Signature

pub const fn from_bytes(bytes: [u8; 64]) -> Self

Create from raw bytes.

pub fn try_from_slice(slice: &[u8]) -> CryptoResult<Self>

Try to create from a slice.

Errors

Returns CryptoError::InvalidSignatureLength if the slice is not exactly 64 bytes.

pub const fn as_bytes(&self) -> &[u8; 64]

Get the raw bytes.

pub fn to_hex(&self) -> String

Encode as hex string.

pub fn from_hex(s: &str) -> CryptoResult<Self>

Decode from hex string.

Errors

Returns an error if the string is not valid hex or not 64 bytes.

pub fn to_base64(&self) -> String

Encode as base64 string.

pub fn from_base64(s: &str) -> CryptoResult<Self>

Decode from base64 string.

Errors

Returns an error if the string is not valid base64 or not 64 bytes.

pub fn verify(&self, message: &[u8], public_key: &[u8; 32]) -> CryptoResult<()>

Verify this signature against a message and public key.

Errors

Returns an error if the public key is invalid or signature verification fails.

pub fn to_dalek(&self) -> DalekSignature

Convert to the underlying dalek signature type.