pub struct Signature(/* private fields */);Expand description
An Ed25519 signature (64 bytes).
Implementations
Sourceimpl Signature
impl Signature
Sourcepub const fn from_bytes(bytes: [u8; 64]) -> Self
pub const fn from_bytes(bytes: [u8; 64]) -> Self
Create from raw bytes.
Sourcepub fn try_from_slice(slice: &[u8]) -> CryptoResult<Self>
pub fn try_from_slice(slice: &[u8]) -> CryptoResult<Self>
Try to create from a slice.
Errors
Returns CryptoError::InvalidSignatureLength if the slice is not exactly 64 bytes.
Sourcepub fn from_hex(s: &str) -> CryptoResult<Self>
pub fn from_hex(s: &str) -> CryptoResult<Self>
Sourcepub fn from_base64(s: &str) -> CryptoResult<Self>
pub fn from_base64(s: &str) -> CryptoResult<Self>
Decode from base64 string.
Errors
Returns an error if the string is not valid base64 or not 64 bytes.
Sourcepub fn verify(&self, message: &[u8], public_key: &[u8; 32]) -> CryptoResult<()>
pub fn verify(&self, message: &[u8], public_key: &[u8; 32]) -> CryptoResult<()>
Verify this signature against a message and public key.
Errors
Returns an error if the public key is invalid or signature verification fails.
Sourcepub fn to_dalek(&self) -> DalekSignature
pub fn to_dalek(&self) -> DalekSignature
Convert to the underlying dalek signature type.